require $env(SCRIPT_HOME)/stylesheet.tcl

# ---- global settings for any RTF file we do ---
rtf:documentFormat {SaveAsRTF 1}
rtf:documentFormat {PaperSize A4}
# ----

proc rtfFileName { filename } {
    foreach realName "$filename ${filename}.gif ${filename}.GIF ${filename}.jpeg ${filename}.JPEG ${filename}.jpg ${filename}.JPG" {
	if { [file readable $realName] } {
	    return $realName
	}
    }
    set fileName [cutGraphicExtensionOff $fileName]
    foreach realName "$filename ${filename}.gif ${filename}.GIF ${filename}.jpeg ${filename}.JPEG ${filename}.jpg ${filename}.JPG" {
	if { [file readable $realName] } {
	    return $realName
	}
    }
    puts stderr "***WARNING: No such file: $fileName\n"
    return
}

proc pageStyle {} {
    rtf:divert Footer
        rtf:startPara style_PageFooter
            pageFooter
        rtf:endPara
    rtf:undivert

    rtf:divert Header
        rtf:startPara style_PageHeader
            pageHeader
        rtf:endPara
    rtf:undivert
}

# Show character with octal CODE from system Symbol font
proc Symbol { code } {
    return "{\\field\\flddirty{\\*\\fldinst SYMBOL $code}{\\fldrslt}}"
}


proc PageRef { id } {
    #    rtf:startField "GOTOBUTTON $id"
    #     rtf:startField "PAGEREF $id"
    #     rtf:write "???"
    #     rtf:endField
    #    rtf:write "???"
    #    rtf:endField
    rtf:bgroup
     rtf:write "\\field\\flddirty"
     rtf:bgroup
      rtf:write "\\*\\fldinst "
      rtf:write [rtf:Escape "GOTOBUTTON $id"]
       rtf:bgroup
       rtf:write "\\field\\flddirty"
        rtf:bgroup
        rtf:write "\\*\\fldinst "
        rtf:write [rtf:Escape "PAGEREF $id"]
       rtf:egroup
       rtf:bgroup
        rtf:write "\\fldrslt "
        rtf:write "???"
       rtf:egroup
      rtf:egroup
     rtf:egroup
     rtf:bgroup
      rtf:write "\\fldrslt "
      rtf:write "???"
     rtf:egroup
    rtf:egroup
}


#FIXMEs:
substitution sFilterSubst {
    {[AElig ]} {AE}
    {[agrave]} {a}
    {[aacute]} {a}
    {[Aacute]} {A}
    {[acirc ]} {a}
    {[Acirc ]} {A}
    {[Agrave]} {A}
    {[aring ]} {a}
    {[Aring ]} {A}
    {[atilde]} {a}
    {[Atilde]} {A}
    {[auml  ]} {a}
    {[Auml  ]} {A}
    {[aelig ]} {ae}
    {[ccedil]} {c}
    {[Ccedil]} {C}
    {[eacute]} {e}
    {[Eacute]} {E}
    {[ecirc ]} {e}
    {[Ecirc ]} {E}
    {[egrave]} {e}
    {[Egrave]} {E}
    {[euml  ]} {e}
    {[Euml  ]} {E}
    {[iacute]} {i}
    {[Iacute]} {I}
    {[icirc ]} {i}
    {[Icirc ]} {I}
    {[igrave]} {i}
    {[Igrave]} {I}
    {[iuml  ]} {i}
    {[Iuml  ]} {I}
    {[ntilde]} {n}
    {[Ntilde]} {N}
    {[oacute]} {o}
    {[Oacute]} {O}
    {[ocirc ]} {o}
    {[Ocirc ]} {O}
    {[ograve]} {o}
    {[Ograve]} {O}
    {[oslash]} {o}
    {[Oslash]} {O}
    {[otilde]} {o}
    {[Otilde]} {O}
    {[ouml  ]} {o}
    {[Ouml  ]} {O}
    {[szlig ]} {ss}
    {[uacute]} {u}
    {[Uacute]} {U}
    {[ucirc ]} {u}
    {[Ucirc ]} {U}
    {[ugrave]} {u}
    {[Ugrave]} {U}
    {[uuml  ]} {u}
    {[Uuml  ]} {U}
    {[yacute]} {y}
    {[Yacute]} {Y}
    {[yuml  ]} {y}
    {[thorn ]} {thorn}
    {[THORN ]} {THORN}
    {[eth   ]} {eth}
    {[ETH   ]} {ETH}
    {[quot  ]} {"}
    {[ldquo ]} {[set rtfSpecial(LDQuote)]}
    {[rdquo ]} {[set rtfSpecial(RDQuote)]}
    {[numero]} {N}
    {[lowbar]} {_}
    {[hellip]} {...}
    {[hyphen]} {-}
    {[percnt]} {%}
    {[rsquo ]} {'}
    {[lsquo ]} {`}
    {[excl  ]} {!}
    {[dollar]} {$}
    {[lsqb  ]} {[}
    {[rsqb  ]} {]}
    {[circ  ]} {^}
    {[bsol  ]} {\\\\}
    {[grave ]} {`}
    {[lcub  ]} {\{}
    {[rcub  ]} {\}}
    {[tilde ]} "~"
    {[verbar]} "|"
    {[lt    ]} "<"
    {[gt    ]} ">"
    {[amp   ]} {&}
    {[ndash ]} {[set rtfSpecial(EnDash)]}
    {[nbsp  ]} {\\~}
    {[laquo ]} {[set rtfSpecial(LDQuote)]}
    {[raquo ]} {[set rtfSpecial(RDQuote)]}
    {[deg   ]} {[Symbol 176]}
    {[sharp ]} {\#}
    {[num   ]} {\#}
    {[mdash ]} {[localize rtfMdash]}
    {[plusmn]} {[Symbol 177]}
    {[prime ]} {[Symbol 162]}
    {[Prime ]} {[Symbol 178]}
    {[tprime]} {'''}
    {[reg   ]} {\\'ae}
    {[trade ]} {\\'99}
}

proc textSdataFilter { text } {
    global rtfSpecial
    debug "text: `$text'"
    return [subst -novariables [sFilterSubst $text]]
}

proc textCdataFilter { text } {
    #FIXME!
    #   [filteredContent]!!!    trim'
    # regsub -all -- "\[ \n\t\]+" [textSdataFilter $text] " " text
    regsub -all -- "\[ \n\t\]+" $text " " text

    return [encoding convertfrom $text]
    
    #FIXME
    withNode parent {
 	if { "[query prev]" != "" } {
 	    return $text
 	}
 	set text [string trimleft $text]
 	if { "[query next]" != "" } {
 	    return [string trimright $text]
 	}
 	return $text
    }
}

proc uniqueID {} {
    set id [query attval ID]
    if { "$id" == "" } {
	set id A[AddrToName [query address]]
    }
    return [MakeRTFmark $id]
}

proc MakeRTFmark { string } {
    return [anyToRTFmarkSubst $string]
}

substitution anyToRTFmarkSubst {
    {.} {_}
}

proc openHeadMark {} {
    withNode parent {
	set id [uniqueID]
    }
    rtf:startBookmark $id
}

proc closeHeadMark {} {
    withNode parent {
	set id [uniqueID]
    }
    rtf:endBookmark $id
}
